@@ -14,9 +14,13 @@ out_missing <- missing_wells(missing, well = 'well')
 
 
 test_that("missing_wells errors when expected",{
-     expect_error( missing_wells(full, well = TRUE))
-     expect_error( missing_wells(full, well = "well", plate = 1))
-     expect_error( missing_wells(full, well = full$well))
+     expect_error(missing_wells(full, well = "well", plate = 1))
+	 expect_error(missing_wells(full, well = TRUE))
+     expect_error(missing_wells(full, well = full$well))
+	 expect_error(missing_wells(as.list(full), well = full$well),
+	 expect_error(missing_wells(full, well = missing$wel)))
+	 expect_error(missing_wells(as.matrix(full), well = full$well))
+	 expect_error(missing_wells(fill, well = full$not_valid_col))
 })
 
 test_that("missing wells doesn't return anything for a full plate",{
@@ -26,4 +30,4 @@ test_that("missing wells doesn't return anything for a full plate",{
 test_that("missing wells return expected answer",{
     expect_equal(length(out_missing), 6L)
     expect_equal(out_missing, num_to_well(91:96))
-})
+})
\ No newline at end of file
